package com.idea.customerManagement.controller;

import com.idea.customerManagement.dto.RoomSelectionInfoDto;
import com.idea.customerManagement.service.RoomSelectionInfoService;
import com.rockstar.common.base.BaseController;
import com.rockstar.common.domain.AjaxResult;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;

@Controller
@RequestMapping(value = "RoomSelectionInfoController")
@Api(tags = "选房管理")
public class RoomSelectionInfoController extends BaseController {

    @Autowired
    private RoomSelectionInfoService modelService;

    /**
     * 选房列表回显
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "listAll",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object list(String customerManagementId){
        List<RoomSelectionInfoDto> result = modelService.listAll(customerManagementId);
        return result;
    }

    /**
     * 选房提交
     * @param houseIds
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "submit",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult submit(String houseIds, String customerManagementId){
        int result = modelService.submit(houseIds,customerManagementId);
        return result(result);
    }

    /**
     * 获取定金流水号
     * @param houseId
     * @return
     */
    @PostMapping(value = "getSerialNumber",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public String getSerialNumber(String houseId) {
        return modelService.getSerialNumber(houseId);
    }

    /**
     * 认购金登记
     * @param model
     * @return
     */
    @PostMapping(value = "add",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult add(RoomSelectionInfoDto model){
        int result = modelService.add(model);
        return result(result);
    }

    /**
     * 认购金修改
     * @param model
     * @return
     */
    @PostMapping(value = "edit",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult edit(RoomSelectionInfoDto model){
        int result = modelService.edit(model);
        return result(result);
    }

    /**
     * 查看详情
     * @param id
     * @return
     */
    @PostMapping(value = "getById",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object getById(String id){
        return modelService.getById(id);
    }


}
