package com.idea.customerManagement.service;

import cn.hutool.core.util.IdUtil;
import com.idea.buildManage.mapper.MnpBuildingMapper;
import com.idea.buildManage.mapper.ParkRoomExtendMapper;
import com.idea.buildManage.mapper.ParkRoomMapper;
import com.idea.buildManage.model.ParkRoom;
import com.idea.buildManage.response.ParkRoomResponse;
import com.idea.customerManagement.dto.RoomSelectionInfoDto;
import com.idea.customerManagement.mapper.CustomerManagementMapper;
import com.idea.customerManagement.mapper.RoomSelectionInfoExtendMapper;
import com.idea.customerManagement.mapper.RoomSelectionInfoMapper;
import com.idea.customerManagement.model.CustomerManagement;
import com.idea.customerManagement.model.RoomSelectionInfo;
import com.idea.customerManagement.model.RoomSelectionInfoExample;
import com.rockstar.common.base.BaseService;
import com.rockstar.shiro.util.ShiroUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Service
public class RoomSelectionInfoService implements BaseService<RoomSelectionInfo, RoomSelectionInfoExample> {

    @Autowired
    private RoomSelectionInfoMapper modelMapper;
    @Autowired
    private RoomSelectionInfoExtendMapper extendMapper;
    @Autowired
    private CustomerManagementMapper customerManagementMapper;
    @Autowired
    private ParkRoomExtendMapper roomExtendMapper;
    @Autowired
    private ContractManageService contractManageService;


    @Override
    public int deleteByPrimaryKey(String s) {
        return modelMapper.deleteByPrimaryKey(s);
    }

    @Override
    public int insertSelective(RoomSelectionInfo roomSelectionInfo) {
        roomSelectionInfo.setId(IdUtil.simpleUUID());
        return modelMapper.insertSelective(roomSelectionInfo);
    }

    public int insertWithoutId(RoomSelectionInfo roomSelectionInfo) {
        return modelMapper.insertSelective(roomSelectionInfo);
    }

    @Override
    public RoomSelectionInfo selectByPrimaryKey(String s) {
        return modelMapper.selectByPrimaryKey(s);
    }

    @Override
    public int updateByPrimaryKeySelective(RoomSelectionInfo roomSelectionInfo) {
        return modelMapper.updateByPrimaryKeySelective(roomSelectionInfo);
    }

    @Override
    public int updateByExampleSelective(RoomSelectionInfo roomSelectionInfo, RoomSelectionInfoExample roomSelectionInfoExample) {
        return modelMapper.updateByExampleSelective(roomSelectionInfo, roomSelectionInfoExample);
    }

    @Override
    public int updateByExample(RoomSelectionInfo roomSelectionInfo, RoomSelectionInfoExample roomSelectionInfoExample) {
        return modelMapper.updateByExample(roomSelectionInfo, roomSelectionInfoExample);
    }

    @Override
    public List<RoomSelectionInfo> selectByExample(RoomSelectionInfoExample roomSelectionInfoExample) {
        return modelMapper.selectByExample(roomSelectionInfoExample);
    }

    @Override
    public long countByExample(RoomSelectionInfoExample roomSelectionInfoExample) {
        return modelMapper.countByExample(roomSelectionInfoExample);
    }

    @Override
    public int deleteByExample(RoomSelectionInfoExample roomSelectionInfoExample) {
        return modelMapper.deleteByExample(roomSelectionInfoExample);
    }

    /**
     * 选房信息列表
     *
     * @param customerManagementId
     * @return
     */
    public List<RoomSelectionInfoDto> listAll(String customerManagementId) {
        List<RoomSelectionInfoDto> result = extendMapper.selectHouseListByCustomerId(customerManagementId);
        return result;
    }

    /**
     * 提交选房
     *
     * @param houseIds
     * @param customerManagementId
     * @return
     */
    public int submit(String houseIds, String customerManagementId) {

        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(customerManagementId);
        customerManagement.setStatus(2);
        customerManagement.setHouseId(houseIds);
        String[] split = houseIds.split(",");
        StringBuilder builder = new StringBuilder();
        // 先删除
        RoomSelectionInfoExample example = new RoomSelectionInfoExample();
        example.createCriteria().andCustomerManagementIdEqualTo(customerManagementId).andHouseIdIn(Arrays.asList(split));
        List<RoomSelectionInfo> list = selectByExample(example);
        if (CollectionUtils.isNotEmpty(list)) {
            for (RoomSelectionInfo info : list) {
                deleteByPrimaryKey(info.getId());
            }
        }
        // 再新增
        for (String s : split) {
            // 拼接房屋名称
            ParkRoomResponse response = roomExtendMapper.getFullName(s);
            builder.append(response.getBuildName()).append("-").append(response.getRoomNo()).append(",");
            // 新增选房信息
            RoomSelectionInfo roomSelectionInfo = new RoomSelectionInfo();
            roomSelectionInfo.setCustomerManagementId(customerManagementId);
            roomSelectionInfo.setHouseId(response.getId());
            roomSelectionInfo.setBuildId(response.getBuildId());
            roomSelectionInfo.setDiscId(response.getDiscId());
            roomSelectionInfo.setGroupId(response.getGroupId());
            roomSelectionInfo.setCreatedAt(new Date());
            roomSelectionInfo.setCreatedId(ShiroUtils.getUserId());
            roomSelectionInfo.setReceivableMoney(response.getSubscriptionFunds());
            roomSelectionInfo.setStatus(1);
            insertSelective(roomSelectionInfo);
        }
        if (builder.length() > 0) {
            builder.deleteCharAt(builder.length() - 1);
        }
        customerManagement.setHouseName(builder.toString());
        customerManagementMapper.updateByPrimaryKeySelective(customerManagement);
        return 1;
    }

    /**
     * 获取收据流水号（定金编号）
     * @param houseId
     * @return
     */
    public String getSerialNumber(String houseId){
        ParkRoomResponse response = roomExtendMapper.getFullName(houseId);
        String groupId = response.getGroupId();
        // 查找这个小区已收取认购金的 数据量
        RoomSelectionInfoExample example = new RoomSelectionInfoExample();
        example.createCriteria().andGroupIdEqualTo(groupId).andStatusEqualTo(2);
        Long count = countByExample(example);
        String number = "";
        if(count.doubleValue() == 0){
            number = "00001";
        }else {
            count ++;
            number = String.format(count.toString(), "%05d", 1);
        }
        String serialNumber = response.getGroupName()+ response.getDiscName() + "-DJ" + number;
        return serialNumber;
    }

    /**
     * 认购金登记
     * @param model
     * @return
     */
    public int add(RoomSelectionInfoDto model){

        model.setUpdatedAt(new Date());
        model.setUpdatedId(ShiroUtils.getUserId());
        model.setStatus(2);
        model.setCollectionId(ShiroUtils.getUserId());
        int result = updateByPrimaryKeySelective(model);
        contractManageService.addContract(model);
        // 生成合同
        return result;
    }

    /**
     * 认购金修改
     * @param model
     * @return
     */
    public int edit(RoomSelectionInfoDto model){

        model.setUpdatedAt(new Date());
        model.setUpdatedId(ShiroUtils.getUserId());
        model.setCollectionId(ShiroUtils.getUserId());
        return updateByPrimaryKeySelective(model);
    }

    /**
     * 查看详情
     * @param id
     * @return
     */
    public RoomSelectionInfo getById(String id){
        return selectByPrimaryKey(id);
    }


}
